%! -*- coding:utf-8; mode:latex; -*-


%% Copyright (c) 20?? Fachschaft Mathematik / Informatik am KIT
%% Copyright (c) 2015 Moritz Klammler <moritz.klammler@student.kit.edu>
%%
%% Permission is hereby granted, free of charge, to any person obtaining a copy
%% of this  software and  associated documentation  files (the  "Software"), to
%% deal in the  Software without restriction, including  without limitation the
%% rights to use, copy, modify,  merge, publish, distribute, sublicense, and/or
%% sell copies of the  Software, and to permit persons to  whom the Software is
%% furnished to do so, subject to the following conditions:
%%
%% The above copyright  notice and this permission notice shall  be included in
%% all copies or substantial portions of the Software.
%%
%% THE SOFTWARE IS  PROVIDED "AS IS", WITHOUT WARRANTY OF  ANY KIND, EXPRESS OR
%% IMPLIED, INCLUDING  BUT NOT  LIMITED TO  THE WARRANTIES  OF MERCHANTABILITY,
%% FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
%% AUTHORS  OR COPYRIGHT  HOLDERS BE  LIABLE FOR  ANY CLAIM,  DAMAGES OR  OTHER
%% LIABILITY,  WHETHER IN  AN ACTION  OF CONTRACT,  TORT OR  OTHERWISE, ARISING
%% FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
%% IN THE SOFTWARE.


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{fsmi-protokoll}[2015/09/11 KIT FSMI oral exam reports]


\LoadClass{article}

\RequirePackage{ifxetex}
\RequirePackage{etoolbox}
\RequirePackage{geometry}

\ifbool{xetex}{
  \RequirePackage{xltxtra}
  \RequirePackage{polyglossia}
  \setmainlanguage[spelling=new]{german}
}{
  \RequirePackage[utf8]{inputenc}
  \RequirePackage[T1]{fontenc}
  \RequirePackage{lmodern}
  \RequirePackage[ngerman]{babel}
}

\RequirePackage{multicol}
\RequirePackage{tabularx}
\RequirePackage{tikz}
\RequirePackage{pifont}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}

\IfFileExists{ragged2e.sty}{%
  % Using ragged2e generally helps reducing troubles in tables.  We don't
  % strictly *need* this so let's make it optional.  I'm also hesitating to
  % load it with the `newcommands` option so we define our own alias.
  \RequirePackage{ragged2e}
  \let\fsmi@raggedright\RaggedRight
}{%
  \let\fsmi@raggedright\raggedright
}

%%     \begin{fsmi@freetextquestion}{QUESTION}{EXPLANATION}
%%       ANSWER...
%%     \end{fsmi@freetextquestion}
%%
%% Typesets a free text question alongside with its answer.  The QUESTION will
%% be printed using an outstanding font.  It must be provided or the result
%% will look awkward.  If the EXPLANATION is non-empty, it will be printed as
%% an additional paragraph below the QUESTION using a smaller font.  The ANSWER
%% follows as zero or more paragraphs containing arbitrary material.  The font
%% for the ANSWER will not be set up to `\fsmi@answerfont` automatically (so
%% you can provide canned answers if you like); this has to be done explicitly.
%%
\newenvironment{fsmi@freetextquestion}[2]{%
  \noindent%
  \begin{tabularx}{\linewidth}{@{}l@{\quad}X@{}}%
    \ding{45} & \bfseries#1%
  \end{tabularx}%
  \ifblank{#2}{}{%
    \par\medskip%
    \noindent\begingroup\small#2\endgroup%
  }%
  \par\bigskip%
}{%
  \par\bigskip%
}

%%     \begin{fsmi@freetextblock}
%%       FREETEXTQUESTION
%%     \end{fsmi@freetextblock}
%%
%% Places FREETEXTQUESTION (which should, but need not strictly, be exactly one
%% `fsmi@freetextquestion` environment) as a `minipage` with a fixed height.
%% This environment may be used to arrange multiple free text questions on a
%% regular grid even if their length varies.
%%
\newenvironment{fsmi@freetextblock}{%
  \setlength{\fsmi@save@parindent}{\parindent}%
  \setlength{\fsmi@save@parskip}{\parskip}%
  \begin{minipage}[t][75mm][t]{0.95\linewidth}%
    \setlength{\parindent}{\fsmi@save@parindent}%
    \setlength{\parskip}{\fsmi@save@parskip}%
}{%
  \end{minipage}%
  \par%
}

%%     \setlength{\fsmi@save@parindent}{\parindent}
%%     \setlength{\parindent}{\fsmi@save@parindent}
%%
%% This length is used to save and restore the value of the `\parindent`
%% length.
%%
\newlength{\fsmi@save@parindent}

%%     \setlength{\fsmi@save@parskip}{\parskip}
%%     \setlength{\parskip}{\fsmi@save@parskip}
%%
%% This length is used to save and restore the value of the `\parskip` length.
%%
\newlength{\fsmi@save@parskip}

%%     \radiobutton{TOGGLENAME}
%%
%% Prints a “radio button”.  If TOGGLENAME -- which must be the name of an
%% *etoolobox* toggle previously created with `\newtoggle` or equivalent -- is
%% set true, the radio button will be checked, otherwise it won't.  To be
%% useful, an invocation of this macro should be followed by some text saying
%% what the button selects.  The box size of the button is guaranteed to be
%% constant whether checked or not.
%%
\newcommand*{\radiobutton}[1]{%
  \begin{tikzpicture}%
    \draw[use as bounding box] (0, 0) circle[radius = 0.7ex];%
    \node at (0, 0) {\iftoggle{#1}{\ding{56}}{}};%
  \end{tikzpicture}%
}

%%     \fsmi@answerfont
%%
%% Switches to the font used for filling in answers to the form questions.  The
%% default is to use an italic font as this looks somehow similar to hand
%% writing.  Re-define this macro if you feel like doing so.
%%
\newcommand*{\fsmi@answerfont}{\itshape}

%%     \fsmi@dunno
%%
%% Prints a special string indicating “no answer” or “unknown”.  This should be
%% used only in form answers.
%%
\newcommand*{\fsmi@dunno}{N/A}

%%     \fsmi@expandordots[DEFAULT]{MACRO}
%%
%% If MACRO is defined, expand it, otherwise, DEFAULT will be expanded.  If no
%% DEFAULT is given, it defaults to `\dotfill`.  In any case, the resulting
%% material will be typeset in `\fsmi@answerfont`.
%%
\newcommand*{\fsmi@expandordots}[2][\dotfill]{%
  \ifdef{#2}{{\fsmi@answerfont#2}}{#1}%
}

%%     \FsmiStudiengang[DEGREE]{NAME}
%%
%% Declares the course of studies to be NAME.  The optional DEGREE may be used
%% to specify the degree awarded for this course.  For example, one might say
%%
%%     \FsmiStudiengang[master]{mathematics}
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@studiengang` to a combination
%% of NAME and DEGREE.
%%
\newcommand*{\FsmiStudiengang}[2][]{%
  \ifblank{#1}{%
    \newcommand*{\@fsmi@studiengang}{#2}%
  }{%
    \newcommand*{\@fsmi@studiengang}{#2 (#1)}%
  }%
}

%% *etoolbox* toggle to indicate that “Wahlpflichtfach” was selected.
\newtoggle{@fsmi@wahlpfl}

%% *etoolbox* toggle to indicate that “Vertiefungsfach” was selected.
\newtoggle{@fsmi@vertief}

%% *etoolbox* toggle to indicate that “Ergänzungsfach” was selected.
\newtoggle{@fsmi@ergaenz}

%%     \FsmiFach[AREA]{CLASS}
%%
%% Declares the class (the “module” in Bologna speak) of the exam to be CLASS.
%% The optional argument may be used to select the are of the class.  The
%% following values are valid:
%%
%% +-----+--------------------+-----------------+
%% | key | selection          | toggle          |
%% +-----+--------------------+-----------------+
%% | `W` | “Wahlpflichtfach”  | `@fsmi@wahlpfl` |
%% | `V` | “Vertiefungsfach”  | `@fsmi@vertief` |
%% | `E` | “Ergänzungsfach”   | `@fsmi@ergaenz` |
%% +-----+--------------------+-----------------+
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@fach` to CLASS.  In addition,
%% if an AREA is specified, the respective toggle will be set true.
%%
\newcommand*{\FsmiFach}[2][]{%
  \newcommand*{\@fsmi@fach}{#2}%
  \ifblank{#1}{}{%
    \ifstrequal{#1}{W}{\toggletrue{@fsmi@wahlpfl}}{%
      \ifstrequal{#1}{V}{\toggletrue{@fsmi@vertief}}{%
        \ifstrequal{#1}{E}{\toggletrue{@fsmi@ergaenz}}{%
          \ClassError{FSMI}{%
            Please answer with {'W', 'V', 'E'}, but not '\protect#1'%
          }{%
            You may omit the optional argument to '\protect\FsmiFach' if
            you don't want to\MessageBreak answer at all.%
          }%
        }%
      }%
    }%
  }%
}

%%     \FsmiDatum{DATE}
%%
%% Declares the date of the exam to be DATE.  It is recommended not to use
%% `\today` as DATE or the document will typeset differently on different days.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@datum` to DATE.
%%
\newcommand*{\FsmiDatum}[1]{%
  \newcommand*{\@fsmi@datum}{#1}%
  % The following check whether `#1` is `\today` is not bullet proof (and
  % arguably ugly) but should catch the most likely case of the deprecated
  % use of `\FsmiDatum{\today}`.
  \newcommand*{\fsmi@today}{\today}%
  \ifdefequal{\@fsmi@datum}{\fsmi@today}{%
    \ClassError{FSMI}{%
      The value of '\protect\today' is subject to change every
      day;\MessageBreak please be more specific%
    }{%
      Please write '\today' rather than '\protect\today' so your document
      will\MessageBreak still produce the correct output if typeset again
      tomorrow.%
    }%
  }{}%
  \undef{\fsmi@today}%
}

%%     \FsmiPrueferIn[COMMENT]{NAME}
%%
%% Declares the examiner to be NAME.  The optional argument may be used to
%% supply additional info (will be typeset as a footnote) about the person; for
%% example, their department or the URL of their website.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@prueferin` to NAME and -- if
%% COMMENT is non-empty -- followed by a respective `\footnote`.
%%
\newcommand*{\FsmiPrueferIn}[2][]{%
  \ifblank{#1}{%
    \newcommand*{\@fsmi@prueferin}{#2}%
  }{%
    \newcommand*{\@fsmi@prueferin}{#2\footnote{#1}}%
  }%
}

%%     \FsmiBeisitzerIn[COMMENT]{NAME}
%%
%% Declares the assessor to be NAME.  The optional argument may be used to
%% supply additional info (will be typeset as a footnote) about the person; for
%% example, their department or the URL of their website.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@prueferin` to NAME and -- if
%% COMMENT is non-empty -- followed by a respective `\footnote`.
%%
\newcommand*{\FsmiBeisitzerIn}[2][]{%
  \ifblank{#1}{%
    \newcommand*{\@fsmi@beisitzerin}{#2}%
  }{%
    \newcommand*{\@fsmi@beisitzerin}{#2\footnote{#1}}%
  }%
}

%%     \FsmiNote[COMMENT]{GRADE}
%%
%% Declares the grade to be GRADE.  The optional COMMENT should be a single
%% sentence telling whether the grade was okay / fair from the candidate's
%% point of view.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@note` to GRADE and the macro
%% `\@fsmi@noteokay` to COMMENT.
%%
\newcommand*{\FsmiNote}[2][\dunno]{%
  \newcommand*{\@fsmi@note}{#2}%
  \newcommand*{\@fsmi@noteokay}{#1}%
}

%%     \FsmiDauer{DURATION}
%%
%% Declares the duration of the exam to be DURATION, which should be a readily
%% formatted string such as “`$\frac{1}{2}$\,h`”.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@dauer` to DURATION.
%%
\newcommand*{\FsmiDauer}[1]{%
  \newcommand*{\@fsmi@dauer}{#1}%
}

%%     \begin{tabular}{llll}
%%       % optional table headings...
%%       \@fsmi@veranst@table
%%     \end{tabular}
%%
%% This is a hook to append rows for the lecture table to.  If properly used,
%% an invocation of this macro in the document body will produce table rows.
%%
\newcommand{\@fsmi@veranst@table}{%
  % initially empty
}

%% Number of rows appended to `\@fsmi@veranst@table` so far.
%%
\newcounter{@fsmi@veranst@count}

%%     \FsmiVeranstaltung{LECTURE}{LECTURER}{YEAR}{ATTENDANCE}
%%
%% Declares that the lecture LECTURE held by LECTURER in YEAR was subject of
%% the exam and that the candidate attended said lecture with ATTENDANCE.
%%
%% This command is to be used any number of times by authors in the preamble of
%% their exam report.  It will append code for an appropriate table row to the
%% `\@fsmi@veranst@table` macro.
%%
\newcommand*{\FsmiVeranstaltung}[4]{%
  \stepcounter{@fsmi@veranst@count}%
  \appto{\@fsmi@veranst@table}{%
    \fsmi@raggedright\fsmi@answerfont#1&%
    \fsmi@raggedright\fsmi@answerfont#2&%
    \fsmi@raggedright\fsmi@answerfont#3&%
    \fsmi@raggedright\fsmi@answerfont#4\cr\hline%
  }%
}

%%     \FsmiPruefungsstil{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Wie war der Prüfungsstil des Prüfers / der Prüferin?”
%% question.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@pruefungsstil` to ANSWER.
%%
\newcommand{\FsmiPruefungsstil}[1]{%
  \newcommand{\@fsmi@pruefungsstil}{#1}%
}

%%     \FsmiBesuchGelohnt{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Hat sich der Besuch / Nichtbesuch der Veranstaltung für dich
%% gelohnt?” question.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@besuchgelohnt` to ANSWER.
%%
\newcommand{\FsmiBesuchGelohnt}[1]{%
  \newcommand{\@fsmi@besuchgelohnt}{#1}%
}

%%     \FsmiVorbereitung{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Wie lange und wie hast du dich alleine oder mit anderen auf
%% die Prüfung vorbereitet?” question.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@vorbereitung` to ANSWER.
%%
\newcommand{\FsmiVorbereitung}[1]{%
  \newcommand{\@fsmi@vorbereitung}{#1}%
}

%%     \FsmiVorbereitungTipps{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Welche Tipps zur Vorbereitung kannst du geben?” question.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@vorbereitungtipps` to ANSWER.
%%
\newcommand{\FsmiVorbereitungTipps}[1]{%
  \newcommand{\@fsmi@vorbereitungtipps}{#1}%
}

%% *etoolbox* toggle to indicate that “yes” was selected (the examiner was
%% recommended).
%%
\newtoggle{@fsmi@rcmd@yes}

%% *etoolbox* toggle to indicate that “no” was selected (the examiner was
%% not recommended).
%%
\newtoggle{@fsmi@rcmd@no}

%%     \FsmiEmpfehlung[SELECTION]{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Kannst du ihn / sie weiterempfehlen? Warum?” question.  The
%% SELECTION may either be `+` (indicating “yes”) or `-` (indicating “no”).
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@empfehlung` to ANSWER.  In
%% addition, if SELECTION was given, the `@fsmi@rcmd@yes` or `@fsmi@rcmd@no`
%% will be set true respectively.
%%
\newcommand{\FsmiEmpfehlung}[2][]{%
  \newcommand{\@fsmi@empfehlung}{#2}%
  \ifblank{#1}{}{%
    \ifstrequal{#1}{+}{\toggletrue{@fsmi@rcmd@yes}}{%
      \ifstrequal{#1}{-}{\toggletrue{@fsmi@rcmd@no}}{%
        \ClassError{FSMI}{%
          Please answer '+' (yes) or '-' (no), but not '\protect#1'%
        }{%
          You may omit the optional argument to '\protect\FsmiEmpfehlung' if
          you don't want to\MessageBreak answer at all.%
        }%
      }%
    }%
  }%
}

%%     \FsmiAbsprachen{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Fanden vor der Prüfung Absprachen zu Form oder Inhalt statt?
%% Wurden sie eingehalten?” question.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@absprachen` to ANSWER.
%%
\newcommand{\FsmiAbsprachen}[1]{%
  \newcommand{\@fsmi@absprachen}{#1}%
}

%%     \FsmiVerhaltenRat{ANSWER}
%%
%% Declares ANSWER (which may be arbitrary multi-paragraph material) as the
%% answer to the “Kannst du Ratschläge für das Verhalten in der Prüfung geben?”
%% question.
%%
%% This command is to be used at most once by authors in the preamble of their
%% exam report.  It will define the macro `\@fsmi@verhaltenrat` to ANSWER.
%%
\newcommand{\FsmiVerhaltenRat}[1]{%
  \newcommand{\@fsmi@verhaltenrat}{#1}%
}

% This `\title`, `\author` and `\date` will not be used by our `\maketitle`
% macro.  Frankly, it is probably completely useless that we provide them here
% at all except that doing so will trigger an error if the user tries to use
% them again which is good because they shall not do so.

\title{Fragebogen zu mündlichen Prüfungen}
\author{Fachschaft Mathematik und Informatik am KIT}
\date{\today}

% The 90 % scale is truly ugly but we need it for the form (where it looks
% okay) and using `\newgeometry` and `\restoregeometry` behaves erratic.  Since
% students are charged per page, I don't feel that bad making the most use of
% the paper.

\geometry{%
  a4paper,%
  scale = 0.9,%
}

\setlength{\parindent}{0em}
\setlength{\parskip}{1ex plus 1ex}

%%     \pgfuseimage{fsmi-logo}
%%
%% Displays the FSMI's owl.
%%
\pgfdeclareimage[width=20mm]{fsmi@logo}{fsmi-logo}

%%     \begin{titlepage}
%%       TITLE MATTER
%%     \end{titlepage}
%%
%% Environment for the title page.  This is meant to be used for all the canned
%% form data.  Inside this environment, `\dunno` will be an alias for
%% `\fsmi@dunno`.
%%
\renewenvironment{titlepage}{%
  \pagestyle{empty}%
  \renewcommand*{\thefootnote}{\fnsymbol{footnote}}%
  \let\dunno\fsmi@dunno%
}{%
  \setcounter{footnote}{0}%
  \pagestyle{plain}%
}

%%     \maketitle
%%
%% Prints the entire two-page canned form incorporating any information
%% provided by the author using the various `\Fsmi*` macros in the preamble.
%%
\renewcommand{\maketitle}{%
  \begin{titlepage}%
    \begin{tikzpicture}%
      \node[inner sep = 0pt] (eule) {\pgfuseimage{fsmi@logo}};%
      \node[anchor = west] at (eule.east) {%
        \Large\fsmi@raggedright\noindent%
        \begin{tabular}{l}%
          Fragebogen der Fachschaft zu\\%
          \textbf{mündlichen Prüfungen}\\%
          im Informatikstudium%
        \end{tabular}%
      };%
    \end{tikzpicture}%
    \par%
    %
    \renewcommand{\arraystretch}{1.8}%
    %
    \noindent%
    \begin{tabularx}{\textwidth}{@{}XX@{}}%
      &%
      \footnotesize\noindent\hfill{Barcode:}\hfill\null%
      \\%
      Dieser Fragebogen gibt den Studierenden, die nach dir die Prüfung ablegen
      wollen, einen Einblick in Ablauf und Inhalt der Prüfung.  Das erleichtert
      die Vorbereitung.

      Bitte verwende zum Ausfüllen einen schwarzen Stift.
      Das erleichtert das Einscannen.

      Vielen Dank für deine Mitarbeit!
      &%
      \noindent$\ulcorner$\hfill$\urcorner$%
      \par\vspace{20mm}%
      \noindent$\llcorner$\hfill$\lrcorner$%
      \par%
      \\%
      %
      \fsmi@raggedright\noindent%
      Dein Studiengang:\quad%
      \fsmi@expandordots{\@fsmi@studiengang}%
      \par\medskip%
      Prüfungsart:\par\smallskip%
      \renewcommand{\arraystretch}{1.0}%
      \begin{tabular}{c@{\enspace}l@{}}%
        \radiobutton{@fsmi@wahlpfl} & Wahlpflichtfach\\%
        \radiobutton{@fsmi@vertief} & Vertiefungsfach\\%
        \radiobutton{@fsmi@ergaenz} & Ergänzungsfach%
      \end{tabular}%
      \par\bigskip%
      \noindent Welches?\quad\fsmi@expandordots{\@fsmi@fach}%
      &%
      \fsmi@raggedright%
      \noindent\makebox[8em][l]{Prüfungsdatum:}%
      \fsmi@expandordots{\@fsmi@datum}%
      \par\bigskip%
      \noindent\makebox[8em][l]{Prüfer(in):}%
      \fsmi@expandordots{\@fsmi@prueferin}%
      \par\bigskip%
      \noindent\makebox[8em][l]{Beisitzer(in):}%
      \fsmi@expandordots{\@fsmi@beisitzerin}%
      \par\bigskip%
    \end{tabularx}%
    \par\bigskip%
    %
    \noindent\textbf{Prüfungsfächer und Vorbereitung:}%
    \par\medskip%
    %
    \noindent%
    \begin{tabularx}{\textwidth}{|X|X|X|X|}%
      \hline%
      Veranstaltung & Dozent(in)  & Jahr & regelmäßig besucht?\\\hline\hline%
      \ifnumgreater{\value{@fsmi@veranst@count}}{0}{%
        \@fsmi@veranst@table%
      }{%
        &&&\cr\hline%
        &&&\cr\hline%
        &&&\cr\hline%
        &&&\cr\hline%
      }%
    \end{tabularx}%
    \par\bigskip%
    %
    \noindent%
    \begin{tabularx}{\textwidth}{@{}XX@{}}%
      Note:\quad%
      \fsmi@expandordots{\@fsmi@note}%
      &%
      Prüfungsdauer:\quad%
      \fsmi@expandordots[\dotfill\quad Minuten]{\@fsmi@dauer}%
    \end{tabularx}%
    \par\bigskip%
    %
    \noindent%
    \begin{tabularx}{\textwidth}{@{}X@{}}%
      \noindent War diese Note angemessen?%
      \quad\fsmi@expandordots{\@fsmi@noteokay}%
    \end{tabularx}%
    \par\bigskip%
    %
    \begin{fsmi@freetextquestion}{%
        Wie war der Prüfungsstil des Prüfers / der Prüferin?
      }{%
        Prüfungsatmosphäre, (un)klare Fragestellungen, Frage nach Einzelheiten
        oder eher größeren Zusammenhängen, kamen häufiger Zwischenfragen oder
        ließ er/sie dich erzählen, wurde dir weitergeholfen, wurde in
        Wissenslücken gebohrt?%
      }%
      \fsmi@expandordots[]{\@fsmi@pruefungsstil}%
    \end{fsmi@freetextquestion}%
    %
    \begin{tikzpicture}[remember picture, overlay]%
      \node[%
        anchor = south east,%
        inner sep = 5mm,%
        font = {\bfseries},%
      ] at (current page.south east) {%
        $\hookrightarrow$\enspace%
        Rückseite bitte nicht vergessen!%
      };%
    \end{tikzpicture}%
    \clearpage%
    %
    \renewcommand{\arraystretch}{1.0}%
    %
    \begin{multicols}{2}%
      %
      \begin{fsmi@freetextblock}%
        \begin{fsmi@freetextquestion}{%
            Hat sich der Besuch / Nichtbesuch der Veranstaltung für dich
            gelohnt?
          }{%
          }%
          \fsmi@expandordots[]{\@fsmi@besuchgelohnt}%
        \end{fsmi@freetextquestion}%
      \end{fsmi@freetextblock}%
      %
      \begin{fsmi@freetextblock}%
        \begin{fsmi@freetextquestion}{%
            Wie lange und wie hast du dich alleine oder mit anderen auf die
            Prüfung vorbereitet?
          }{%
          }%
          \fsmi@expandordots[]{\@fsmi@vorbereitung}%
        \end{fsmi@freetextquestion}%
      \end{fsmi@freetextblock}%
      %
      \begin{fsmi@freetextblock}%
        \begin{fsmi@freetextquestion}{%
            Welche Tipps zur Vorbereitung kannst du geben?
          }{%
            Wichtige / unwichtige Teile des Stoffes, gute Bücher / Skripten,
            Lernstil, \dots%
          }%
          \fsmi@expandordots[]{\@fsmi@vorbereitungtipps}%
        \end{fsmi@freetextquestion}%
      \end{fsmi@freetextblock}%
      %
      \begin{fsmi@freetextblock}%
        \begin{fsmi@freetextquestion}{%
            Kannst du ihn / sie weiterempfehlen?  Warum?
          }{%
          }%
          \noindent%
          \begin{tabular}{c@{\enspace}l}%
            \radiobutton{@fsmi@rcmd@yes} & ja\\%
            \radiobutton{@fsmi@rcmd@no}  & nein%
          \end{tabular}%
          \par\bigskip%
          \fsmi@expandordots[]{\@fsmi@empfehlung}%
        \end{fsmi@freetextquestion}%
      \end{fsmi@freetextblock}%
      %
      \begin{fsmi@freetextblock}%
        \begin{fsmi@freetextquestion}{%
            Fanden vor der Prüfung Absprachen zu Form oder Inhalt statt?
            Wurden sie eingehalten?
          }{%
          }%
          \fsmi@expandordots[]{\@fsmi@absprachen}%
        \end{fsmi@freetextquestion}%
      \end{fsmi@freetextblock}%
      %
      \begin{fsmi@freetextblock}%
        \begin{fsmi@freetextquestion}{%
            Kannst du Ratschläge für das Verhalten in der Prüfung geben?
          }{%
          }%
          \fsmi@expandordots[]{\@fsmi@verhaltenrat}%
        \end{fsmi@freetextquestion}%
      \end{fsmi@freetextblock}%
      %
    \end{multicols}%
    \vfill%
    %
    \textbf{Inhalte der Prüfung (bitte auf weitere Blätter):}%
    \begin{itemize}%
    \item Schreibe bitte möglichst viele Fragen und Antworten auf.
    \item Wo wurde nach Herleitungen oder Beweisen gefragt oder sonstwie
      nachgehakt?
    \item Worauf wollte der Prüfer / die Prüferin hinaus?
    \item Welche Fragen gehörten nicht zum eigentlichen Stoff?
    \end{itemize}%
    \cleardoublepage%
  \end{titlepage}%
}
